emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/ef-themes c11d7b7671 2/2: Make theme one-line descripti


From: ELPA Syncer
Subject: [elpa] externals/ef-themes c11d7b7671 2/2: Make theme one-line descriptions more descriptive
Date: Tue, 6 Sep 2022 23:57:35 -0400 (EDT)

branch: externals/ef-themes
commit c11d7b767134be9a7b91453e2792fe009c7529b7
Author: Protesilaos Stavrou <info@protesilaos.com>
Commit: Protesilaos Stavrou <info@protesilaos.com>

    Make theme one-line descriptions more descriptive
---
 ef-autumn-theme.el    | 4 ++--
 ef-dark-theme.el      | 4 ++--
 ef-day-theme.el       | 4 ++--
 ef-duo-dark-theme.el  | 4 ++--
 ef-duo-light-theme.el | 4 ++--
 ef-light-theme.el     | 4 ++--
 ef-night-theme.el     | 4 ++--
 ef-spring-theme.el    | 4 ++--
 ef-summer-theme.el    | 4 ++--
 ef-winter-theme.el    | 4 ++--
 10 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/ef-autumn-theme.el b/ef-autumn-theme.el
index b85df2deb4..8bb0964850 100644
--- a/ef-autumn-theme.el
+++ b/ef-autumn-theme.el
@@ -1,4 +1,4 @@
-;;; ef-autumn-theme.el --- Legible dark theme with warm colors -*- 
lexical-binding:t -*-
+;;; ef-autumn-theme.el --- Legible dark theme with warm, varied colors (red, 
yellow, green, teal) -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-autumn "Legible dark theme with warm colors.")
+  (deftheme ef-autumn "Legible dark theme with warm, varied colors (red, 
yellow, green, teal).")
 
   (defconst ef-autumn-palette
     '(;; Basic tones
diff --git a/ef-dark-theme.el b/ef-dark-theme.el
index 429c7ee065..b4efee30e7 100644
--- a/ef-dark-theme.el
+++ b/ef-dark-theme.el
@@ -1,4 +1,4 @@
-;;; ef-dark-theme.el --- Legible dark theme with blue and magenta colors -*- 
lexical-binding:t -*-
+;;; ef-dark-theme.el --- Legible dark theme with blue, magenta, cyan, purple 
colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-dark "Legible dark theme with blue and magenta colors.")
+  (deftheme ef-dark "Legible dark theme with blue, magenta, cyan, purple 
colors.")
 
   (defconst ef-dark-palette
     '(;; Basic tones
diff --git a/ef-day-theme.el b/ef-day-theme.el
index 7d0a4ab48b..6d197bcecb 100644
--- a/ef-day-theme.el
+++ b/ef-day-theme.el
@@ -1,4 +1,4 @@
-;;; ef-day-theme.el --- Legible light theme with warm colors -*- 
lexical-binding:t -*-
+;;; ef-day-theme.el --- Legible light theme with warm, varied colors (yellow, 
red, green, purple) -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-day "Legible light theme with warm colors.")
+  (deftheme ef-day "Legible light theme with warm, varied colors (yellow, red, 
green, purple).")
 
   (defconst ef-day-palette
     '(;; Basic tones
diff --git a/ef-light-theme.el b/ef-light-theme.el
index ca129830f8..b13df6daca 100644
--- a/ef-light-theme.el
+++ b/ef-light-theme.el
@@ -1,4 +1,4 @@
-;;; ef-light-theme.el --- Legible light theme with blue and magenta colors -*- 
lexical-binding:t -*-
+;;; ef-light-theme.el --- Legible light theme with blue, magenta, cyan, purple 
colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-light "Legible light theme with blue and magenta colors.")
+  (deftheme ef-light "Legible light theme with blue, magenta, cyan, purple 
colors.")
 
   (defconst ef-light-palette
     '(;; Basic tones
diff --git a/ef-night-theme.el b/ef-night-theme.el
index b311a725a9..bcf2845631 100644
--- a/ef-night-theme.el
+++ b/ef-night-theme.el
@@ -1,4 +1,4 @@
-;;; ef-night-theme.el --- Legible dark theme with cool colors -*- 
lexical-binding:t -*-
+;;; ef-night-theme.el --- Legible dark theme with mostly green, blue, purple 
colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-night "Legible dark theme with cool colors.")
+  (deftheme ef-night "Legible dark theme with mostly green, blue, purple 
colors.")
 
   (defconst ef-night-palette
     '(;; Basic tones
diff --git a/ef-summer-theme.el b/ef-summer-theme.el
index b0a7182b83..72347d29f6 100644
--- a/ef-summer-theme.el
+++ b/ef-summer-theme.el
@@ -1,4 +1,4 @@
-;;; ef-summer-theme.el --- Legible light theme with magenta, purple, gold 
colors -*- lexical-binding:t -*-
+;;; ef-summer-theme.el --- Legible light theme with magenta, purple, gold, 
cyan colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-summer "Legible light theme with magenta, purple, gold colors.")
+  (deftheme ef-summer "Legible light theme with magenta, purple, gold, cyan 
colors.")
 
   (defconst ef-summer-palette
     '(;; Basic tones
diff --git a/ef-winter-theme.el b/ef-winter-theme.el
index 8514519daf..a6afda1136 100644
--- a/ef-winter-theme.el
+++ b/ef-winter-theme.el
@@ -1,4 +1,4 @@
-;;; ef-winter-theme.el --- Legible dark theme with magenta, purple, gold 
colors -*- lexical-binding:t -*-
+;;; ef-winter-theme.el --- Legible dark theme with magenta, purple, fawn, teal 
colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-winter "Legible dark theme with magenta, purple, gold colors.")
+  (deftheme ef-winter "Legible dark theme with magenta, purple, fawn, teal 
colors.")
 
   (defconst ef-winter-palette
     '(;; Basic tones



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/ef-duo-dark-theme.el b/ef-duo-dark-theme.el
index ef63c50e92..a568989887 100644
--- a/ef-duo-dark-theme.el
+++ b/ef-duo-dark-theme.el
@@ -1,4 +1,4 @@
 ;;; ef-duo-dark-theme.el --- Legible dark theme with blue and yellow colors 
 *- lexical-binding:t -*-
colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -40,7 +40,7 @@
   ;; Most of the colors here are defined simply to preserve
   ;; compatibility with the rest of the project.  We don't actually rely
   ;; on them for anything critical.
-  (deftheme ef-duo-dark "Legible dark theme with blue and yellow colors.")
+  (deftheme ef-duo-dark "Legible dark theme with mostly blue and yellow 
colors.")
 
   (defconst ef-duo-dark-palette
@@ -1,4 +1,4 @@
-;;; ef-duo-dark-theme.el --- Legible dark theme with blue and yellow colors 
-*- lexical-binding:t -*-
+;;; ef-duo-dark-theme.el --- Legible dark theme with mostly blue and yellow 
colors -*- lexical-binding:t -*-
 
     '(;; Basic tones
diff --git a/ef-duo-light-theme.el b/ef-duo-light-theme.el
index b48718dd30..02a130e715 100644
--- a/ef-duo-light-theme.el
+++ b/ef-duo-light-theme.el
@@ -1,4 +1,4 @@
 ;;; ef-duo-light-theme.el --- Legible light theme with blue and yellow colors 
 *- lexical-binding:t -*-
colors -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -40,7 +40,7 @@
   ;; Most of the colors here are defined simply to preserve
   ;; compatibility with the rest of the project.  We don't actually rely
   ;; on them for anything critical.
-  (deftheme ef-duo-light "Legible light theme with blue and yellow colors.")
+  (deftheme ef-duo-light "Legible light theme with mostly blue and yellow 
colors.")
 
   (defconst ef-duo-light-palette
@@ -1,4 +1,4 @@
-;;; ef-duo-light-theme.el --- Legible light theme with blue and yellow colors 
-*- lexical-binding:t -*-
+;;; ef-duo-light-theme.el --- Legible light theme with mostly blue and yellow 
colors -*- lexical-binding:t -*-
 
     '(;; Basic tones
diff --git a/ef-spring-theme.el b/ef-spring-theme.el
index 54e3949a1f..48c3b6ba8b 100644
--- a/ef-spring-theme.el
+++ b/ef-spring-theme.el
@@ -1,4 +1,4 @@
 ;;; ef-spring-theme.el --- Legible light theme with cool, green, red colors 
 *- lexical-binding:t -*-
(green, cyan, red) -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
@@ -37,7 +37,7 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-spring "Legible light theme with cool, green, red colors.")
+  (deftheme ef-spring "Legible light theme with cool, varied colors (green, 
cyan, red).")
 
   (defconst ef-spring-palette
@@ -1,4 +1,4 @@
-;;; ef-spring-theme.el --- Legible light theme with cool, green, red colors 
-*- lexical-binding:t -*-
+;;; ef-spring-theme.el --- Legible light theme with cool, varied colors 
(green, cyan, red) -*- lexical-binding:t -*-
 
     '(;; Basic tones